@@ -24,6 +24,7 @@ namespace installer {
 
 namespace {
 
+const char kSystemShutdown[] =  "/sbin/shutdown";
 const char kSystemCtlCmd[] = "systemctl";
 const char kSysReqTriggerFile[] = "/proc/sysrq-trigger";
 
@@ -38,6 +39,10 @@ bool RebootSystemWithMagicKey() {
 }
 
 bool ShutdownSystem() {
+  return SpawnCmd(kSystemShutdown, {"-h", "now"});
+}
+
+bool PoweroffSystem() {
   return SpawnCmd(kSystemCtlCmd, {"poweroff"});
 }
 
@@ -45,4 +50,4 @@ bool ShutdownSystemWithMagicKey() {
   return WriteTextFile(kSysReqTriggerFile, "o");
 }
 
-}  // namespace installer
\ No newline at end of file
+}  // namespace installer
