@@ -11,6 +11,7 @@
 #include <QDebug>
 #include <QScreen>
 #include <QThread>
+#include <stdlib.h>
 
 DWIDGET_USE_NAMESPACE
 
@@ -103,6 +104,15 @@ double installer::ScreenAdaptationManager::getHeightZoomRatio() const
     return m_heightZoomRatio;
 }
 
+void installer::ScreenAdaptationManager::initDpiScale()
+{
+    int dpiVal = int(qApp->primaryScreen()->logicalDotsPerInch());
+    int p_dpiVal = int(qApp->primaryScreen()->physicalDotsPerInch());
+
+    installer::SetSettingString("DI_LOGICAL_DPI", QString::number(dpiVal));
+    installer::SetSettingString("DI_PHYSICAL_DPI", QString::number(p_dpiVal));
+}
+
 
 void installer::ScreenAdaptationManager::setup(const QRect &rect)
 {
