@@ -155,7 +155,7 @@ bool SystemInfoFramePrivate::validateHostname(QString &msg)
             return false;
         }
         case ValidateHostnameState::InvalidChar: {
-            msg = ::QObject::tr("Computer name is invalid");
+            msg = ::QObject::tr("Computer name can only contain letters, numbers, and dashes (-), and cannot start or end with a dash (-)");
             return false;
         }
         case ValidateHostnameState::ReservedError: {
@@ -170,6 +170,13 @@ bool SystemInfoFramePrivate::validateHostname(QString &msg)
                     .arg(kHostnameMaxLen);
             return false;
         }
+        case ValidateHostnameState::LabelTooLongError: {
+            msg = ::QObject::tr("Please input a computer name longer than %1 characters and "
+                     "shorter than %2 characters")
+                    .arg(kHostnameMinLen)
+                    .arg(LabelMaxLen);
+            return false;
+        }
         case ValidateHostnameState::Ok: {
             // Pass
             break;
@@ -180,11 +187,10 @@ bool SystemInfoFramePrivate::validateHostname(QString &msg)
 
 bool SystemInfoFramePrivate::validateUsername(QString &msg)
 {
-    const QString reserved_username_file = GetReservedUsernameFile();
         const int min_len = GetSettingsInt(kSystemInfoUsernameMinLen);
         const int max_len = GetSettingsInt(kSystemInfoUsernameMaxLen);
-        const ValidateUsernameState state = ValidateUsername(m_le_username->text()
-                                                             , reserved_username_file, min_len, max_len);
+
+        const ValidateUsernameState state = ValidateUsername(m_le_username->text(), min_len, max_len);
         switch (state) {
         case ValidateUsernameState::ReservedError: {
             msg = ::QObject::tr("This username already exists");
@@ -195,15 +201,14 @@ bool SystemInfoFramePrivate::validateUsername(QString &msg)
             return false;
         }
         case ValidateUsernameState::EmptyError:  // fall through
+        case ValidateUsernameState::Digital:
         case ValidateUsernameState::InvalidCharError: {
-            msg = ::QObject::tr("Username must contain English letters (lowercase), "
-                       "numbers or special symbols (_-)");
+            msg = ::QObject::tr("Username must start with letters or numbers, only contain letters, numbers, dashes (-) and underscores (_), and cannot use numbers alone");
             return false;
         }
         case ValidateUsernameState::TooLongError:  // fall through
         case ValidateUsernameState::TooShortError: {
-            msg = ::QObject::tr("Please input a username longer than %1 characters and "
-                     "shorter than %2 characters")
+            msg = ::QObject::tr("Username must be between %1 and %2 characters")
                     .arg(min_len)
                     .arg(max_len);
             return false;
