@@ -4,7 +4,6 @@
 #include <QWidget>
 #include <QResizeEvent>
 
-class QStackedLayout;
 class QVBoxLayout;
 
 namespace installer {
@@ -19,13 +18,13 @@ public:
     void eraseContent();
 
 protected:
-    void paintEvent(QPaintEvent* event) override;
+    void showEvent(QShowEvent *event) override;
+    void closeEvent(QCloseEvent *event) override;
 
 private:
     BaseFrameInterface* m_childFrameInterface;
-    QStackedLayout* m_centerLayout;
-
-    QWidget* m_widget;
+    QVBoxLayout* m_centerLayout;
+    QWidget* m_centerWidget;
 };
 }
 #endif // PARTITION_SHADOW_WIDGET_H
